require "src/objects"
Player = {}
Player.__index = Player
ActivePlayers = {}

function Player.new(x, y)
    local instance = setmetatable({}, Player)
    instance.x = x 
    instance.y = y 
    instance.w = 50
    instance.h = 50
    instance.speed = 6
    instance.jump = 400
    instance.friction = 800
    instance.fallForce = 400
    instance.grounded = true
    instance.allowPosX = true
    instance.allowNegX = true
    instance.xVel = 0 
    instance.yVel = 0
    return instance
end

function Player:update(dt)
    self:movement(dt)
    self:fall(dt)
    self:Jump(dt)
    self:collide()
end

function Player:movement(dt)
    self.x, self.y = self.x + self.xVel, self.y + self.yVel
    if love.keyboard.isDown("a") and self.allowNegX then 
        self.xVel = -self.speed
    elseif love.keyboard.isDown("d") and self.allowPosX then 
        self.xVel = self.speed
    else 
        self.xVel = 0
    end
end

function Player:fall(dt)
    if not self.grounded then
        self.yVel = self.fallForce * dt
    elseif self.grounded then  
       self.yVel = 0 
    end
end

function Player:Jump(dt)
    local dt = love.timer.getDelta()
    if love.keyboard.isDown("space") and self.grounded then 
        self.yVel = self.yVel - self.jump
        self.grounded = false
    end
end


function Player:draw()
    love.graphics.rectangle("fill", self.x, self.y, self.w, self.h)
end


function Player:collide()
    for i, b in ipairs(blocks) do 
        if aabb(self, b) then --collide(self.x, self.y, self.w, self.h, b.x, b.y, b.w, b.h) then
            self:solveCollision(b)
            if self.x > b.x then 
                self.xVel = 0 
            end
            if self.x < b.x then 
                self.xVel = 0 
            end
            if self.y < b.y then 
                self.grounded = true
            end
        end
    end
end

function Player:solveCollision(b)
    if self.x > b.x then 
        local wert1 = b.x - self.x + b.w
        self.x = self.x + wert1
    end
    if self.x < b.x then 
        local wert2 = b.x - self.x - b.w
        self.x = self.x + wert2
    end
    if self.y > b.y then 
       local wert3 = b.y - self.y + b.h
       self.y = self.y + wert3
    end
    if self.y < b.y then
        local wert4 = b.y - self.y - b.h
        self.y = self.y + wert4
    end
end